@@ -3,16 +3,15 @@ from pydoc import locate
 from bravado.exception import HTTPError
 
 from django.db import models, transaction
+from django.db.models import Case, Value, When
 from django.utils.timezone import now
-
-from allianceauth.services.hooks import get_extension_logger
-
 from esi.models import Token
 
-from . import __title__
-from .helpers.esi_fetch import esi_fetch_with_localization, esi_fetch
-from .utils import LoggerAddTag, make_logger_prefix
+from allianceauth.services.hooks import get_extension_logger
+from app_utils.logging import LoggerAddTag, make_logger_prefix
 
+from . import __title__
+from .helpers.esi_fetch import esi_fetch, esi_fetch_with_localization
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -103,10 +102,10 @@ class EveUniverseManager(models.Manager):
 class EveSovereigntyMapManager(models.Manager):
     def update_from_esi(self):
         logger.info("Fetching sovereignty map from ESI...")
-        map = esi_fetch("Sovereignty.get_sovereignty_map", args={})
+        sov_map = esi_fetch("Sovereignty.get_sovereignty_map", args={})
         last_updated = now()
         obj_list = list()
-        for solar_system in map:
+        for solar_system in sov_map:
             obj_def = {
                 "solar_system_id": solar_system["system_id"],
                 "last_updated": last_updated,
@@ -183,6 +182,19 @@ class EveEntityManager(models.Manager):
 
 
 class StructureManager(models.Manager):
+    def select_related_defaults(self) -> models.QuerySet:
+        """returns a QuerySet with the default select_related"""
+        return self.select_related(
+            "owner",
+            "owner__corporation",
+            "owner__corporation__alliance",
+            "eve_type",
+            "eve_solar_system",
+            "eve_solar_system__eve_constellation__eve_region",
+            "eve_planet",
+            "eve_moon",
+        )
+
     def get_or_create_esi(self, structure_id: int, token: Token) -> tuple:
         """get or create a structure with data from ESI if needed
 
@@ -253,11 +265,11 @@ class StructureManager(models.Manager):
     def update_or_create_from_dict(self, structure: dict, owner: object) -> tuple:
         """update or create structure from given dict"""
         from .models import (
-            EveType,
-            EveSolarSystem,
-            StructureService,
-            EvePlanet,
             EveMoon,
+            EvePlanet,
+            EveSolarSystem,
+            EveType,
+            StructureService,
         )
         from .models.eveuniverse import EveUniverse
 
@@ -432,3 +444,22 @@ class StructureTagManager(models.Manager):
             },
         )
         return obj, created
+
+
+class NotificationQuerySet(models.QuerySet):
+    def annotate_can_be_rendered(self) -> models.QuerySet:
+        """annotates field indicating if a notification can be rendered"""
+        from .models import NotificationType
+
+        return self.annotate(
+            can_be_rendered_2=Case(
+                When(notif_type__in=NotificationType.values, then=True),
+                default=Value(False),
+                output_field=models.BooleanField(),
+            )
+        )
+
+
+class NotificationManager(models.Manager):
+    def get_queryset(self) -> models.QuerySet:
+        return NotificationQuerySet(self.model, using=self._db)
