@@ -3,16 +3,16 @@
 import urllib
 
 from django.db import models
-from django.utils.translation import gettext
 from django.utils import translation
 from django.utils.timezone import now
+from django.utils.translation import gettext
 
 from allianceauth.eveonline.models import EveCorporationInfo
 from allianceauth.services.hooks import get_extension_logger
+from app_utils.logging import LoggerAddTag
 
 from .. import __title__
-from ..managers import EveUniverseManager, EveSovereigntyMapManager
-from app_utils.logging import LoggerAddTag
+from ..managers import EveSovereigntyMapManager, EveUniverseManager
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -303,6 +303,7 @@ class EveGroup(EveUniverse):
 
     EVE_GROUP_ID_CONTROL_TOWER = 365
     EVE_GROUP_ID_FUEL_BLOCK = 1136
+    EVE_GROUP_ID_REFINERY = 1406
 
     eve_category = models.ForeignKey(
         EveCategory, on_delete=models.SET_DEFAULT, null=True, default=None, blank=True
